@@ -16,8 +16,8 @@ class biosample(SQLModel, table=True):  # type: ignore
     name: str = Field(default=None, index=True)
     batch: Optional[str] = None
     species_id: int = Field(default=None, foreign_key="species.id")
-    tissue_id: str = Field(default=None, foreign_key="tissue.id")
-    cell_type_id: str = Field(default=None, foreign_key="cell_type.id")
-    disease_id: str = Field(default=None, foreign_key="disease.id")
-    cell_marker_id: str = Field(default=None, foreign_key="cell_marker.id")
+    tissue_id: int = Field(default=None, foreign_key="tissue.id")
+    cell_type_id: int = Field(default=None, foreign_key="cell_type.id")
+    disease_id: int = Field(default=None, foreign_key="disease.id")
+    cell_marker_id: int = Field(default=None, foreign_key="cell_marker.id")
     techsample_id: int = Field(default=None, foreign_key="techsample.id")
