@@ -55,7 +55,7 @@ class experiment(SQLModel, table=True):  # type: ignore
     exp_id: str = Field(default=None, unique=True)
     name: Optional[str] = None
     date: Optional[str] = None
-    project: str = Field(default=None, foreign_key="project.id")
+    project_id: str = Field(default=None, foreign_key="project.id")
     experiment_type_id: int = Field(default=None, foreign_key="experiment_type.id")
     time_created: datetime = Field(default_factory=utcnow, nullable=False)
 
